# Generated by Django 3.1.7 on 2021-02-27 06:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('tickle', '0002_auto_20210226_0543'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='pitch',
            options={'ordering': ('order',), 'verbose_name_plural': 'Pitches'},
        ),
        migrations.AlterField(
            model_name='area',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='tickle.area'),
        ),
        migrations.AlterField(
            model_name='attempt',
            name='boulder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='attempts', to='tickle.boulder'),
        ),
        migrations.AlterField(
            model_name='attempt',
            name='route',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='attempts', to='tickle.route'),
        ),
        migrations.AlterField(
            model_name='boulder',
            name='area',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='boulders', to='tickle.area'),
        ),
        migrations.AlterField(
            model_name='route',
            name='area',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='routes', to='tickle.area'),
        ),
        migrations.AlterField(
            model_name='todo',
            name='boulder',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='todos', to='tickle.boulder'),
        ),
        migrations.AlterField(
            model_name='todo',
            name='route',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='todos', to='tickle.route'),
        ),
    ]



# Generated by Django 3.1.7 on 2021-02-27 19:08

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('tickle', '0003_auto_20210227_0609'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attempt',
            name='result',
            field=models.CharField(choices=[('send', 'Sent'), ('fall', 'Fall'), ('unknown', 'Unknown')], max_length=8),
        ),
        migrations.AlterField(
            model_name='attempt',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='attempts', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='todo',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='todos', to=settings.AUTH_USER_MODEL),
        ),
    ]
